@@ -189,7 +189,7 @@ class MarkdownMode(defaultmode.DefaultMode):
 
             if not stack:
                 header = self.HeaderInfo('namespace', None, name, name, 
-                            None, pos)
+                            None, m.start())
                 yield header
                 stack.append((level, header))
                 continue
@@ -206,7 +206,7 @@ class MarkdownMode(defaultmode.DefaultMode):
 
             header = self.HeaderInfo(
                 'namespace', parent, name, 
-                name, None, pos)
+                name, None, m.start())
             yield header
             stack.append((level, header))
             
