@@ -9,21 +9,21 @@ class TestDefaultMode(kaa_testutils._TestScreenBase):
         doc.setmode(mode)
 
         assert (
-            (0, 4, '0123'),
-            (4, 8, '   \t'),
-            (8, 11, 'abc'),
-            (11, 12, ' '),
-            (12, 16, '::::'),
-            (16, 21, 'あいうえお'),
-            (21, 26, 'カキクケコ'),
-            (26, 28, '[[')) == tuple(mode.split_word(0))
+            (0, 4, '0123', 'L_WORDCHAR'),
+            (4, 8, '   \t', 'Z_WHITESPACE'),
+            (8, 11, 'abc', 'L_WORDCHAR'),
+            (11, 12, ' ', 'Z_WHITESPACE'),
+            (12, 16, '::::', 'Po'),
+            (16, 21, 'あいうえお', 'L_HIRAGANA'),
+            (21, 26, 'カキクケコ', 'L_KATAKANA'),
+            (26, 28, '[[', 'Ps'),) == tuple(mode.split_word(0))
 
         mode = self._getmode()
         doc = self._getdoc('\n\n')
         doc.setmode(mode)
 
         assert (
-            (0, 1, '\n'),
+            (0, 1, '\n', '_LF'),
         ) == tuple(mode.split_word(0))
 
     def test_search_next(self):
